[asterisk-scf-commits] asterisk-scf/integration/sip.git branch "master" updated.

Commits to the Asterisk SCF project code repositories asterisk-scf-commits at lists.digium.com
Tue Oct 26 10:02:24 CDT 2010


branch "master" has been updated
       via  fb46c4170b543f00db6d4f8f2286eeefa3ffb9d6 (commit)
       via  20fb053c10599eae068ececa485ce08804306fe2 (commit)
       via  d92b0e34f07b4bb15e7a8767fca7a716778b049e (commit)
      from  282673221e779b3828b28637ed767160d65498ab (commit)

Summary of changes:
 CMakeLists.txt                                     |    4 +-
 config/test_sip.conf                               |   10 +-
 local-slice/CMakeLists.txt                         |    8 +-
 local-slice/SipIf.ice                              |    6 +-
 slice                                              |    2 +-
 src/CMakeLists.txt                                 |   88 ++++++++++----------
 src/PJSipLoggingModule.cpp                         |    4 +-
 src/PJSipLoggingModule.h                           |    2 +-
 src/PJSipLoggingModuleConstruction.cpp             |    2 +-
 src/PJSipManager.cpp                               |    6 +-
 src/PJSipManager.h                                 |    4 +-
 src/PJSipModule.cpp                                |    4 +-
 src/PJSipModule.h                                  |    4 +-
 src/PJSipSessionModule.cpp                         |    6 +-
 src/PJSipSessionModule.h                           |    4 +-
 src/PJSipSessionModuleConstruction.cpp             |   20 ++--
 src/ProxyWrapper.h                                 |    4 +-
 src/SipEndpoint.cpp                                |   10 +-
 src/SipEndpoint.h                                  |    8 +-
 src/SipEndpointFactory.cpp                         |    4 +-
 src/SipEndpointFactory.h                           |    4 +-
 src/SipSession.cpp                                 |    6 +-
 src/SipSession.h                                   |    4 +-
 ...nnelServiceApp.cpp => SipSessionManagerApp.cpp} |   70 ++++++++--------
 ...or.cpp => SipSessionManagerEndpointLocator.cpp} |    8 +-
 ...ocator.h => SipSessionManagerEndpointLocator.h} |   10 +-
 ...her.cpp => SipSessionManagerEventPublisher.cpp} |   28 +++---
 ...blisher.h => SipSessionManagerEventPublisher.h} |   12 ++--
 src/SipStateReplicator.h                           |    2 +-
 src/SipStateReplicatorListener.cpp                 |    2 +-
 test/CMakeLists.txt                                |    2 +-
 31 files changed, 174 insertions(+), 174 deletions(-)
 rename src/{SipChannelServiceApp.cpp => SipSessionManagerApp.cpp} (90%)
 rename src/{SipChannelServiceEndpointLocator.cpp => SipSessionManagerEndpointLocator.cpp} (86%)
 rename src/{SipChannelServiceEndpointLocator.h => SipSessionManagerEndpointLocator.h} (85%)
 rename src/{SipChannelServiceEventPublisher.cpp => SipSessionManagerEventPublisher.cpp} (77%)
 rename src/{SipChannelServiceEventPublisher.h => SipSessionManagerEventPublisher.h} (81%)


- Log -----------------------------------------------------------------
commit fb46c4170b543f00db6d4f8f2286eeefa3ffb9d6
Author: Joshua Colp <jcolp at digium.com>
Date:   Tue Oct 26 10:04:22 2010 -0400

    Eep! Some more!

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 9f00737..6900dba 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -6,7 +6,7 @@
 # All rights reserved.
 #
 
-# SIP Channel Service build system
+# SIP Session Manager build system
 
 if(NOT integrated_build STREQUAL "true")
 
@@ -17,7 +17,7 @@ if(NOT integrated_build STREQUAL "true")
    include(cmake/AsteriskSCF.cmake)
 
    # This project is C++ based and requires a minimum of 3.4 of Ice. 
-   asterisk_scf_project(SipChannelService 3.4 CXX)
+   asterisk_scf_project(SipSessionManager 3.4 CXX)
 
    # Include pjproject build integration
    include(cmake/modules/pjproject.cmake)

commit 20fb053c10599eae068ececa485ce08804306fe2
Author: Joshua Colp <jcolp at digium.com>
Date:   Tue Oct 26 10:03:40 2010 -0400

    Remove another Channel Service reference.

diff --git a/test/CMakeLists.txt b/test/CMakeLists.txt
index b89b678..ef8ba28 100644
--- a/test/CMakeLists.txt
+++ b/test/CMakeLists.txt
@@ -1 +1 @@
-# SIP Channel Service test driver 
+# SIP Session Manager test driver 

commit d92b0e34f07b4bb15e7a8767fca7a716778b049e
Author: Joshua Colp <jcolp at digium.com>
Date:   Tue Oct 26 10:02:40 2010 -0400

    Switch from referring to things as Channel Service to Session Manager as previously discussed.

diff --git a/config/test_sip.conf b/config/test_sip.conf
index 7c108a5..407c56c 100644
--- a/config/test_sip.conf
+++ b/config/test_sip.conf
@@ -3,13 +3,13 @@
 # Adapter parameters for this component
 # The IP address and port specified here *must* match between master and slave
 # for Ice proxies to remain valid.
-SipChannelServiceAdapter.Endpoints=tcp -p 9985
-SipChannelServiceAdapter.ThreadPool.Size=4
+SipSessionManagerAdapter.Endpoints=tcp -p 9985
+SipSessionManagerAdapter.ThreadPool.Size=4
 
 # Adapter parameters for the object adapter unique to this instance of the component
 # This should have a specified IP address and port so the replica control utility can find it.
-SipChannelServiceLocalAdapter.Endpoints=default
-SipChannelServiceLocalAdapter.ThreadPool.Size=4
+SipSessionManagerLocalAdapter.Endpoints=default
+SipSessionManagerLocalAdapter.ThreadPool.Size=4
 
 # A proxy to the IceStorm topic manager
 TopicManager.Proxy=AsteriskSCFIceStorm/TopicManager:default -p 10000
@@ -46,4 +46,4 @@ Sip.Endpoint.18005558355.Session.CallDirection=Both
 Sip.Endpoint.18005558355.Session.SourceAddress=172.16.1.13
 Sip.Endpoint.18005558355.Transport.Address=172.16.1.10
 
-IceBox.Service.SipChannelService=SipChannelService:create --Ice.Config=config/test_sip.conf
+IceBox.Service.SipSessionManager=SipSessionManager:create --Ice.Config=config/test_sip.conf
diff --git a/local-slice/CMakeLists.txt b/local-slice/CMakeLists.txt
index 11cd75b..a886e38 100644
--- a/local-slice/CMakeLists.txt
+++ b/local-slice/CMakeLists.txt
@@ -1,5 +1,5 @@
-# Compile SIP Channel Service Component's own slice
+# Compile SIP Session Manager Component's own slice
 asterisk_scf_slice_include_directories("${CMAKE_SOURCE_DIR}/slice") 
-asterisk_scf_compile_slice(SipIf.ice lib "SIP Service Slice Types" SipChannelService)
-asterisk_scf_compile_slice(SipStateReplicationIf.ice lib "SIP State Replicator" SipChannelService)
-#asterisk_scf_compile_slice(SipConfigurationIf.ice lib "SIP Configuration Slice Types" SipChannelService)
+asterisk_scf_compile_slice(SipIf.ice lib "SIP Service Slice Types" SipSessionManager)
+asterisk_scf_compile_slice(SipStateReplicationIf.ice lib "SIP State Replicator" SipSessionManager)
+#asterisk_scf_compile_slice(SipConfigurationIf.ice lib "SIP Configuration Slice Types" SipSessionManager)
diff --git a/local-slice/SipIf.ice b/local-slice/SipIf.ice
index d040fc6..9a03f60 100644
--- a/local-slice/SipIf.ice
+++ b/local-slice/SipIf.ice
@@ -8,7 +8,7 @@ module SIP
 module V1
 {
    const string Version = "V1";
-   const string ComponentServiceDiscoveryCategory = "SipChannelService";
+   const string ComponentServiceDiscoveryCategory = "SipSessionManager";
 
    // A submodule for our event publication.
    module Event
@@ -22,9 +22,9 @@ module V1
    };
    
    /**
-    * Interface for monitoring the SIP Channel Service events. 
+    * Interface for monitoring the SIP Session Manager events. 
     */
-   interface SipChannelServiceEvents
+   interface SipSessionManagerEvents
    {
       /**
        * Notification that a lookup was attempted on our published EndpointLocator.
diff --git a/slice b/slice
index 0c62939..df22de4 160000
--- a/slice
+++ b/slice
@@ -1 +1 @@
-Subproject commit 0c629393e2f05dc0ed43bcc6305880949df36289
+Subproject commit df22de4cdfa237ab7cbabbc8af895de73f554a9a
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index a15e17f..15cb230 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -1,47 +1,47 @@
-# Define the SIP Channel Service component
+# Define the SIP Session Manager component
 
-asterisk_scf_component_init(SipChannelService CXX)
+asterisk_scf_component_init(SipSessionManager CXX)
 
-asterisk_scf_component_add_slice(SipChannelService RoutingIf)
-asterisk_scf_component_add_slice(SipChannelService ServiceLocatorIf)
-asterisk_scf_component_add_slice(SipChannelService EndpointIf)
-asterisk_scf_component_add_slice(SipChannelService ComponentServiceIf)
-asterisk_scf_component_add_slice(SipChannelService MediaIf)
-asterisk_scf_component_add_slice(SipChannelService MediaRTPIf)
-asterisk_scf_component_add_slice(SipChannelService SessionCommunicationsIf)
-asterisk_scf_component_add_slice(SipChannelService SipStateReplicationIf)
-asterisk_scf_component_add_slice(SipChannelService ReplicaIf)
+asterisk_scf_component_add_slice(SipSessionManager RoutingIf)
+asterisk_scf_component_add_slice(SipSessionManager ServiceLocatorIf)
+asterisk_scf_component_add_slice(SipSessionManager EndpointIf)
+asterisk_scf_component_add_slice(SipSessionManager ComponentServiceIf)
+asterisk_scf_component_add_slice(SipSessionManager MediaIf)
+asterisk_scf_component_add_slice(SipSessionManager MediaRTPIf)
+asterisk_scf_component_add_slice(SipSessionManager SessionCommunicationsIf)
+asterisk_scf_component_add_slice(SipSessionManager SipStateReplicationIf)
+asterisk_scf_component_add_slice(SipSessionManager ReplicaIf)
 
 # Add our component's own slice types.
-asterisk_scf_component_add_slice(SipChannelService SipIf)
-
-asterisk_scf_component_add_file(SipChannelService SipChannelServiceApp.cpp)
-asterisk_scf_component_add_file(SipChannelService SipChannelServiceEventPublisher.cpp)
-asterisk_scf_component_add_file(SipChannelService SipChannelServiceEventPublisher.h)
-asterisk_scf_component_add_file(SipChannelService SipChannelServiceEndpointLocator.cpp)
-asterisk_scf_component_add_file(SipChannelService SipChannelServiceEndpointLocator.h)
-asterisk_scf_component_add_file(SipChannelService SipEndpointFactory.cpp)
-asterisk_scf_component_add_file(SipChannelService SipEndpointFactory.h)
-asterisk_scf_component_add_file(SipChannelService SipEndpoint.cpp)
-asterisk_scf_component_add_file(SipChannelService SipEndpoint.h)
-asterisk_scf_component_add_file(SipChannelService SipSession.cpp)
-asterisk_scf_component_add_file(SipChannelService SipSession.h)
-asterisk_scf_component_add_file(SipChannelService PJSipManager.cpp)
-asterisk_scf_component_add_file(SipChannelService PJSipManager.h)
-asterisk_scf_component_add_file(SipChannelService PJSipModule.cpp)
-asterisk_scf_component_add_file(SipChannelService PJSipModule.h)
-asterisk_scf_component_add_file(SipChannelService PJSipSessionModule.cpp)
-asterisk_scf_component_add_file(SipChannelService PJSipSessionModuleConstruction.cpp)
-asterisk_scf_component_add_file(SipChannelService PJSipSessionModule.h)
-asterisk_scf_component_add_file(SipChannelService PJSipLoggingModule.cpp)
-asterisk_scf_component_add_file(SipChannelService PJSipLoggingModuleConstruction.cpp)
-asterisk_scf_component_add_file(SipChannelService PJSipLoggingModule.h)
-asterisk_scf_component_add_file(SipChannelService SipStateReplicatorListener.cpp)
-asterisk_scf_component_add_file(SipChannelService SipStateReplicator.h)
-
-asterisk_scf_component_add_ice_libraries(SipChannelService IceStorm)
-
-asterisk_scf_component_add_boost_libraries(SipChannelService thread core)
+asterisk_scf_component_add_slice(SipSessionManager SipIf)
+
+asterisk_scf_component_add_file(SipSessionManager SipSessionManagerApp.cpp)
+asterisk_scf_component_add_file(SipSessionManager SipSessionManagerEventPublisher.cpp)
+asterisk_scf_component_add_file(SipSessionManager SipSessionManagerEventPublisher.h)
+asterisk_scf_component_add_file(SipSessionManager SipSessionManagerEndpointLocator.cpp)
+asterisk_scf_component_add_file(SipSessionManager SipSessionManagerEndpointLocator.h)
+asterisk_scf_component_add_file(SipSessionManager SipEndpointFactory.cpp)
+asterisk_scf_component_add_file(SipSessionManager SipEndpointFactory.h)
+asterisk_scf_component_add_file(SipSessionManager SipEndpoint.cpp)
+asterisk_scf_component_add_file(SipSessionManager SipEndpoint.h)
+asterisk_scf_component_add_file(SipSessionManager SipSession.cpp)
+asterisk_scf_component_add_file(SipSessionManager SipSession.h)
+asterisk_scf_component_add_file(SipSessionManager PJSipManager.cpp)
+asterisk_scf_component_add_file(SipSessionManager PJSipManager.h)
+asterisk_scf_component_add_file(SipSessionManager PJSipModule.cpp)
+asterisk_scf_component_add_file(SipSessionManager PJSipModule.h)
+asterisk_scf_component_add_file(SipSessionManager PJSipSessionModule.cpp)
+asterisk_scf_component_add_file(SipSessionManager PJSipSessionModuleConstruction.cpp)
+asterisk_scf_component_add_file(SipSessionManager PJSipSessionModule.h)
+asterisk_scf_component_add_file(SipSessionManager PJSipLoggingModule.cpp)
+asterisk_scf_component_add_file(SipSessionManager PJSipLoggingModuleConstruction.cpp)
+asterisk_scf_component_add_file(SipSessionManager PJSipLoggingModule.h)
+asterisk_scf_component_add_file(SipSessionManager SipStateReplicatorListener.cpp)
+asterisk_scf_component_add_file(SipSessionManager SipStateReplicator.h)
+
+asterisk_scf_component_add_ice_libraries(SipSessionManager IceStorm)
+
+asterisk_scf_component_add_boost_libraries(SipSessionManager thread core)
 
 if(NOT logger_dir)
    message(FATAL_ERROR "The logger directory could not be found ${logger_dir}")
@@ -49,16 +49,16 @@ endif()
 include_directories(${logger_dir}/common)
 include_directories(${logger_dir}/client/src)
 
-asterisk_scf_component_build_icebox(SipChannelService)
+asterisk_scf_component_build_icebox(SipSessionManager)
 
-target_link_libraries(SipChannelService logging-client)
+target_link_libraries(SipSessionManager logging-client)
 
-pjproject_link(SipChannelService pjsip)
-pjproject_link(SipChannelService pjmedia)
-pjproject_link(SipChannelService pjlib-util)
-pjproject_link(SipChannelService pjlib)
+pjproject_link(SipSessionManager pjsip)
+pjproject_link(SipSessionManager pjmedia)
+pjproject_link(SipSessionManager pjlib-util)
+pjproject_link(SipSessionManager pjlib)
 
-#asterisk_scf_component_install(SipChannelService RUNTIME bin "SIP Channel Service" SipChannelService)
+#asterisk_scf_component_install(SipSessionManager RUNTIME bin "SIP Session Manager" SipSessionManager)
 
 asterisk_scf_component_init(SipStateReplicator CXX)
 
diff --git a/src/PJSipLoggingModule.cpp b/src/PJSipLoggingModule.cpp
index 884cc48..74fae5b 100644
--- a/src/PJSipLoggingModule.cpp
+++ b/src/PJSipLoggingModule.cpp
@@ -21,13 +21,13 @@ using namespace AsteriskSCF::System::Logging;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 pj_status_t PJSipLoggingModule::load(pjsip_endpoint *endpt)
diff --git a/src/PJSipLoggingModule.h b/src/PJSipLoggingModule.h
index 0ccfa7b..dcfce4c 100644
--- a/src/PJSipLoggingModule.h
+++ b/src/PJSipLoggingModule.h
@@ -21,7 +21,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 class PJSipLoggingModule : public PJSipModule
diff --git a/src/PJSipLoggingModuleConstruction.cpp b/src/PJSipLoggingModuleConstruction.cpp
index 110669c..06e5475 100644
--- a/src/PJSipLoggingModuleConstruction.cpp
+++ b/src/PJSipLoggingModuleConstruction.cpp
@@ -19,7 +19,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 static PJSipLoggingModule *loggingModule;
diff --git a/src/PJSipManager.cpp b/src/PJSipManager.cpp
index 8c592a0..4554e70 100644
--- a/src/PJSipManager.cpp
+++ b/src/PJSipManager.cpp
@@ -21,14 +21,14 @@ using namespace AsteriskSCF::System::Logging;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 static void *monitorThread(void *endpt)
@@ -139,6 +139,6 @@ bool PJSipManager::setTransports(pjsip_endpoint *endpoint, Ice::PropertiesPtr pr
    return true;
 }
 
-}; //End namespace SipChannelService
+}; //End namespace SipSessionManager
 
 }; //End namespace AsteriskSCF
diff --git a/src/PJSipManager.h b/src/PJSipManager.h
index b6808b3..da115c1 100644
--- a/src/PJSipManager.h
+++ b/src/PJSipManager.h
@@ -31,7 +31,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 /**
@@ -92,6 +92,6 @@ private:
 	bool setTransports(pjsip_endpoint *endpoint, Ice::PropertiesPtr props);
 };
 
-}; //End namespace SipChannelService
+}; //End namespace SipSessionManager
 
 }; //End namespace AsteriskSCF
diff --git a/src/PJSipModule.cpp b/src/PJSipModule.cpp
index 416c968..ba4de0a 100644
--- a/src/PJSipModule.cpp
+++ b/src/PJSipModule.cpp
@@ -22,13 +22,13 @@ using namespace AsteriskSCF::System::Logging;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 //Arbitrarily chosen URI size. Used for times when I need
diff --git a/src/PJSipModule.h b/src/PJSipModule.h
index b02d201..d96aa76 100644
--- a/src/PJSipModule.h
+++ b/src/PJSipModule.h
@@ -27,7 +27,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 using namespace AsteriskSCF::SIP::V1;
@@ -76,5 +76,5 @@ private:
 	TransactionState transactionStateTranslate(pjsip_tsx_state_e state);
 };
 
-}; //end namespace SipChannelService
+}; //end namespace SipSessionManager
 }; //end namespace AsteriskSCF
diff --git a/src/PJSipSessionModule.cpp b/src/PJSipSessionModule.cpp
index 602d190..64567d6 100644
--- a/src/PJSipSessionModule.cpp
+++ b/src/PJSipSessionModule.cpp
@@ -32,13 +32,13 @@ using namespace AsteriskSCF::System::Logging;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 using namespace AsteriskSCF::Core::Routing::V1;
@@ -1041,5 +1041,5 @@ pjsip_dialog *PJSipSessionModule::uaOnDialogForked(pjsip_dialog *first_set, pjsi
    return NULL;
 }
 
-}; //end namespace SipChannelService
+}; //end namespace SipSessionManager
 }; //end namespace AsteriskSCF
diff --git a/src/PJSipSessionModule.h b/src/PJSipSessionModule.h
index 271056f..c10cbf2 100644
--- a/src/PJSipSessionModule.h
+++ b/src/PJSipSessionModule.h
@@ -32,7 +32,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 class PJSipSessionModInfo
@@ -95,5 +95,5 @@ private:
 	AsteriskSCF::System::Component::V1::ReplicaPtr mReplica;
 };
 
-}; //end namespace SipChannelService
+}; //end namespace SipSessionManager
 }; //end namespace AsteriskSCF
diff --git a/src/PJSipSessionModuleConstruction.cpp b/src/PJSipSessionModuleConstruction.cpp
index 673f06b..63dd7ed 100644
--- a/src/PJSipSessionModuleConstruction.cpp
+++ b/src/PJSipSessionModuleConstruction.cpp
@@ -19,7 +19,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 static PJSipSessionModule *sessionModule;
@@ -116,20 +116,20 @@ PJSipSessionModule::PJSipSessionModule(pjsip_endpoint *endpt,
 	if (pjsip_ua_instance()->id == -1)
 	{
 		pj_bzero(&mUaParam, sizeof(&mUaParam));
-		mUaParam.on_dlg_forked = AsteriskSCF::SipChannelService::uaOnDialogForked;
+		mUaParam.on_dlg_forked = AsteriskSCF::SipSessionManager::uaOnDialogForked;
 	}
 
 	if (pjsip_inv_usage_instance()->id == -1)
 	{
 		pj_bzero(&mInvCallback, sizeof(mInvCallback));
-		mInvCallback.on_state_changed = AsteriskSCF::SipChannelService::invOnStateChanged;
-		mInvCallback.on_new_session = AsteriskSCF::SipChannelService::invOnNewSession;
-		mInvCallback.on_tsx_state_changed = AsteriskSCF::SipChannelService::invOnTsxStateChanged;
-		mInvCallback.on_rx_offer = AsteriskSCF::SipChannelService::invOnRxOffer;
-		mInvCallback.on_create_offer = AsteriskSCF::SipChannelService::invOnCreateOffer;
-		mInvCallback.on_media_update = AsteriskSCF::SipChannelService::invOnMediaUpdate;
+		mInvCallback.on_state_changed = AsteriskSCF::SipSessionManager::invOnStateChanged;
+		mInvCallback.on_new_session = AsteriskSCF::SipSessionManager::invOnNewSession;
+		mInvCallback.on_tsx_state_changed = AsteriskSCF::SipSessionManager::invOnTsxStateChanged;
+		mInvCallback.on_rx_offer = AsteriskSCF::SipSessionManager::invOnRxOffer;
+		mInvCallback.on_create_offer = AsteriskSCF::SipSessionManager::invOnCreateOffer;
+		mInvCallback.on_media_update = AsteriskSCF::SipSessionManager::invOnMediaUpdate;
 		//mInvCallback.on_send_ack = invOnSendAck;
-		mInvCallback.on_redirected = AsteriskSCF::SipChannelService::invOnRedirected;
+		mInvCallback.on_redirected = AsteriskSCF::SipSessionManager::invOnRedirected;
 	}
 	
 	pjsip_tsx_layer_init_module(endpt);
@@ -142,5 +142,5 @@ PJSipSessionModule::PJSipSessionModule(pjsip_endpoint *endpt,
 	pjsip_endpt_register_module(endpt, &mModule);
 }
 
-}; //end namespace SipChannelService
+}; //end namespace SipSessionManager
 }; //end namespace AsteriskSCF
diff --git a/src/ProxyWrapper.h b/src/ProxyWrapper.h
index 6bc7e0c..05f69b5 100644
--- a/src/ProxyWrapper.h
+++ b/src/ProxyWrapper.h
@@ -14,7 +14,7 @@
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 /**
@@ -150,5 +150,5 @@ private:
 	bool mInitialized;
 };
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
diff --git a/src/SipEndpoint.cpp b/src/SipEndpoint.cpp
index 159eeea..1efe730 100644
--- a/src/SipEndpoint.cpp
+++ b/src/SipEndpoint.cpp
@@ -28,12 +28,12 @@ using namespace AsteriskSCF::System::Logging;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 /**
@@ -226,14 +226,14 @@ AsteriskSCF::SessionCommunications::V1::SessionPrx SipEndpoint::createSession(co
    return session->getSessionProxy();
 }
 
-AsteriskSCF::SipChannelService::SipSessionPtr SipEndpoint::createSession(const std::string& destination)
+AsteriskSCF::SipSessionManager::SipSessionPtr SipEndpoint::createSession(const std::string& destination)
 {
    SipSessionPtr session = new SipSession(mImplPriv->mAdapter, this, destination, 0, mImplPriv->mManager, mImplPriv->mServiceLocator, mImplPriv->mReplica);
    mImplPriv->mSessions.push_back(session);
    return session;
 }
 
-AsteriskSCF::SipChannelService::SipSessionPtr SipEndpoint::createSession(const std::string& destination, const Ice::Identity& sessionid,
+AsteriskSCF::SipSessionManager::SipSessionPtr SipEndpoint::createSession(const std::string& destination, const Ice::Identity& sessionid,
    const Ice::Identity& mediaid, const AsteriskSCF::Media::V1::SessionPrx& mediasession,
    const AsteriskSCF::Media::V1::StreamSourceSeq& sources,
    const AsteriskSCF::Media::V1::StreamSinkSeq& sinks)
@@ -276,5 +276,5 @@ AsteriskSCF::SessionCommunications::V1::SessionEndpointPrx SipEndpoint::getEndpo
    return mImplPriv->mEndpointProxy;
 }
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
diff --git a/src/SipEndpoint.h b/src/SipEndpoint.h
index e02825b..45a374e 100644
--- a/src/SipEndpoint.h
+++ b/src/SipEndpoint.h
@@ -37,7 +37,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 class SipEndpointFactory;
@@ -228,8 +228,8 @@ public:
    AsteriskSCF::SessionCommunications::V1::SessionEndpointPrx getEndpointProxy();
 
    // TODO: Find a way to use SipSessionPtr here, right now trying to do so results in the world exploding due to dependency insanity
-   AsteriskSCF::SipChannelService::SipSessionPtr createSession(const std::string&);
-   AsteriskSCF::SipChannelService::SipSessionPtr createSession(const std::string&, const Ice::Identity&, const Ice::Identity&,
+   AsteriskSCF::SipSessionManager::SipSessionPtr createSession(const std::string&);
+   AsteriskSCF::SipSessionManager::SipSessionPtr createSession(const std::string&, const Ice::Identity&, const Ice::Identity&,
 							       const AsteriskSCF::Media::V1::SessionPrx&, const AsteriskSCF::Media::V1::StreamSourceSeq&,
 							       const AsteriskSCF::Media::V1::StreamSinkSeq&);
 
@@ -260,6 +260,6 @@ private:
  */
 typedef IceUtil::Handle<SipEndpoint> SipEndpointPtr;
 
-}; //End namespace SipChannelService
+}; //End namespace SipSessionManager
 
 }; //End namespace AsteriskSCF
diff --git a/src/SipEndpointFactory.cpp b/src/SipEndpointFactory.cpp
index 2d8a254..6d360e1 100644
--- a/src/SipEndpointFactory.cpp
+++ b/src/SipEndpointFactory.cpp
@@ -19,7 +19,7 @@
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 SipEndpointPtr SipEndpointFactory::createEndpoint(std::string destination, Ice::PropertiesPtr props)
@@ -60,5 +60,5 @@ void SipEndpointFactory::generateRoutingDestinations(AsteriskSCF::Core::Routing:
    }
 }
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
diff --git a/src/SipEndpointFactory.h b/src/SipEndpointFactory.h
index f16a179..74d4235 100644
--- a/src/SipEndpointFactory.h
+++ b/src/SipEndpointFactory.h
@@ -25,7 +25,7 @@
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 /**
@@ -75,5 +75,5 @@ private:
    AsteriskSCF::System::Component::V1::ReplicaPtr mReplica;
 };
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
diff --git a/src/SipSession.cpp b/src/SipSession.cpp
index 365eb20..e1ef1c9 100644
--- a/src/SipSession.cpp
+++ b/src/SipSession.cpp
@@ -30,12 +30,12 @@ using namespace AsteriskSCF::System::Logging;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 class SipMediaSession : public Media::V1::Session
@@ -757,5 +757,5 @@ bool SipSession::operator==(const SipSession &other) const {
    return (this->mImplPriv->mInviteSession == other.mImplPriv->mInviteSession);
 }
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
diff --git a/src/SipSession.h b/src/SipSession.h
index c02faf5..8ced355 100644
--- a/src/SipSession.h
+++ b/src/SipSession.h
@@ -39,7 +39,7 @@
 namespace AsteriskSCF
 {
 
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 class SipEndpoint;
@@ -139,6 +139,6 @@ private:
  */
 typedef IceUtil::Handle<SipSession> SipSessionPtr;
 
-}; //End namespace SipChannelService
+}; //End namespace SipSessionManager
 
 }; //End namespace AsteriskSCF
diff --git a/src/SipChannelServiceEndpointLocator.cpp b/src/SipSessionManagerEndpointLocator.cpp
similarity index 86%
rename from src/SipChannelServiceEndpointLocator.cpp
rename to src/SipSessionManagerEndpointLocator.cpp
index 715fedb..19a74b0 100644
--- a/src/SipChannelServiceEndpointLocator.cpp
+++ b/src/SipSessionManagerEndpointLocator.cpp
@@ -18,15 +18,15 @@
 #include <boost/shared_ptr.hpp>
 
 #include "SipEndpointFactory.h"
-#include "SipChannelServiceEndpointLocator.h"
+#include "SipSessionManagerEndpointLocator.h"
 #include "SipEndpoint.h"
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
-AsteriskSCF::Core::Endpoint::V1::EndpointSeq SipChannelServiceEndpointLocator::lookup(const ::std::string& destination, const Ice::Current&)
+AsteriskSCF::Core::Endpoint::V1::EndpointSeq SipSessionManagerEndpointLocator::lookup(const ::std::string& destination, const Ice::Current&)
 {
 	AsteriskSCF::Core::Endpoint::V1::EndpointSeq endpoints;
 	SipEndpointPtr endpoint = mEndpointFactory->findByName(destination);
@@ -39,6 +39,6 @@ AsteriskSCF::Core::Endpoint::V1::EndpointSeq SipChannelServiceEndpointLocator::l
 	return endpoints;
 }
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
 
diff --git a/src/SipChannelServiceEventPublisher.h b/src/SipSessionManagerEventPublisher.h
similarity index 81%
rename from src/SipChannelServiceEventPublisher.h
rename to src/SipSessionManagerEventPublisher.h
index 38edd70..691c538 100644
--- a/src/SipChannelServiceEventPublisher.h
+++ b/src/SipSessionManagerEventPublisher.h
@@ -22,17 +22,17 @@
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
-class SipChannelServiceEventPublisherPriv;
+class SipSessionManagerEventPublisherPriv;
 
 /**
  * Publishes key events to the rest of the system. 
  */
-class SipChannelServiceEventPublisher 
+class SipSessionManagerEventPublisher 
 {
 public:
-   SipChannelServiceEventPublisher(Ice::ObjectAdapterPtr adapter); 
+   SipSessionManagerEventPublisher(Ice::ObjectAdapterPtr adapter); 
 
    /**
     * Send a message to the service's event topic to report a lookup event.
@@ -44,9 +44,9 @@ public:
 
 
 private:
-   boost::shared_ptr<SipChannelServiceEventPublisherPriv> mImpl; // pimpl idiom applied. 
+   boost::shared_ptr<SipSessionManagerEventPublisherPriv> mImpl; // pimpl idiom applied. 
 };
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
 
diff --git a/src/SipStateReplicator.h b/src/SipStateReplicator.h
index e667ad8..3f00416 100644
--- a/src/SipStateReplicator.h
+++ b/src/SipStateReplicator.h
@@ -23,7 +23,7 @@
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 using namespace AsteriskSCF::SIP::V1;
 #if 0
diff --git a/src/SipStateReplicatorListener.cpp b/src/SipStateReplicatorListener.cpp
index 9fa98ec..c5f5d70 100644
--- a/src/SipStateReplicatorListener.cpp
+++ b/src/SipStateReplicatorListener.cpp
@@ -27,7 +27,7 @@
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 using namespace AsteriskSCF::SIP::V1;

-----------------------------------------------------------------------


diff --git a/src/SipChannelServiceApp.cpp b/src/SipSessionManagerApp.cpp
similarity index 90%
rename from src/SipChannelServiceApp.cpp
rename to src/SipSessionManagerApp.cpp
index 5a26e3d..5a56fd4 100644
--- a/src/SipChannelServiceApp.cpp
+++ b/src/SipSessionManagerApp.cpp
@@ -31,8 +31,8 @@
 #include "IceLogger.h"
 #include "logger.h"
 
-#include "SipChannelServiceEventPublisher.h"
-#include "SipChannelServiceEndpointLocator.h"
+#include "SipSessionManagerEventPublisher.h"
+#include "SipSessionManagerEndpointLocator.h"
 #include "SipEndpointFactory.h"
 #include "PJSipSessionModule.h"
 #include "PJSipManager.h"
@@ -41,7 +41,7 @@
 #include "ProxyWrapper.h"
 
 using namespace std;
-using namespace AsteriskSCF::SipChannelService;
+using namespace AsteriskSCF::SipSessionManager;
 using namespace AsteriskSCF::Core;
 using namespace AsteriskSCF::Core::Routing::V1;
 using namespace AsteriskSCF::Core::Discovery::V1;
@@ -51,22 +51,22 @@ using namespace AsteriskSCF::SessionCommunications::V1;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 /**
  * This private class initializes the startup and controls the shutdown of the component.
  */
-class SipChannelService : public IceBox::Service
+class SipSessionManager : public IceBox::Service
 {
 public:
-   SipChannelService() : mDone(false) {}
-   ~SipChannelService()
+   SipSessionManager() : mDone(false) {}
+   ~SipSessionManager()
    {
       // Smart pointers do your thing.
       mReplicaService = 0;
@@ -117,7 +117,7 @@ private:
    ProxyWrapper<SipStateReplicatorPrx> mStateReplicator;
    ProxyWrapper<SessionRouterPrx> mSessionRouter;
    ProxyWrapper<LocatorRegistryPrx> mRoutingServiceLocatorRegistry;
-   boost::shared_ptr<SipChannelServiceEventPublisher> mEventPublisher;
+   boost::shared_ptr<SipSessionManagerEventPublisher> mEventPublisher;
    Routing::V1::EndpointLocatorPtr mEndpointLocator;
 };
 
@@ -132,7 +132,7 @@ static const string ReplicaServiceId("SipChannelReplica");
 class ComponentServiceImpl : public ComponentService
 {
 public:
-   ComponentServiceImpl(SipChannelService &service) : mService(service) {}
+   ComponentServiceImpl(SipSessionManager &service) : mService(service) {}
 
 public: // Overrides of the ComponentService interface.
    virtual void suspend(const ::Ice::Current& = ::Ice::Current())
@@ -151,7 +151,7 @@ public: // Overrides of the ComponentService interface.
    }
 
 private:
-   SipChannelService& mService;
+   SipSessionManager& mService;
 };
 
 /**
@@ -271,7 +271,7 @@ private:
  * Helper function to add some parameters to one of our registered interfaces in the ServiceLocator, so that
  * other components can look up our interfaces.
  */
-void SipChannelService::setCategory(Discovery::V1::ServiceManagementPrx serviceManagement, const string &category)
+void SipSessionManager::setCategory(Discovery::V1::ServiceManagementPrx serviceManagement, const string &category)
 {
    // Add category as a parameter to enable other components look this component up.
    ServiceLocatorParamsPtr genericparams = new ServiceLocatorParams();
@@ -283,7 +283,7 @@ void SipChannelService::setCategory(Discovery::V1::ServiceManagementPrx serviceM
  * Register this component's primary public interfaces with the Service Locator.
  * This enables other Asterisk SCF components to locate our interfaces.
  */
-void SipChannelService::registerWithServiceLocator()
+void SipSessionManager::registerWithServiceLocator()
 {
    try
    {
@@ -301,7 +301,7 @@ void SipChannelService::registerWithServiceLocator()
       ComponentServicePrx componentServicePrx = ComponentServicePrx::checkedCast(componentServiceObjectPrx);
 
       // The GUID passed in to add service needs to be unique for reporting.
-      string componentServiceGuid("SipChannelService");
+      string componentServiceGuid("SipSessionManager");
       mComponentServiceManagement = ServiceManagementPrx::uncheckedCast(mServiceLocatorManagement->addService(componentServicePrx, componentServiceGuid));
 
       setCategory(mComponentServiceManagement, AsteriskSCF::SIP::V1::ComponentServiceDiscoveryCategory);
@@ -317,9 +317,9 @@ void SipChannelService::registerWithServiceLocator()
 /**
  * Register our own Endpoint Locator with the Routing Service so that
  * the endpoints that this channel manages can be accessed from any
  * channel service in the Asterisk SCF system.
  */
-void SipChannelService::registerWithRoutingService()
+void SipSessionManager::registerWithRoutingService()
 {
    RegExSeq destinations;
 
@@ -334,7 +334,7 @@ void SipChannelService::registerWithRoutingService()
 /**
  * Deregister our own Endpoint Locator from the Routing SErvice.
  */
-void SipChannelService::deregisterFromRoutingService()
+void SipSessionManager::deregisterFromRoutingService()
 {
    mRoutingServiceLocatorRegistry->removeEndpointLocator("pjsip");
 }
@@ -343,7 +343,7 @@ void SipChannelService::deregisterFromRoutingService()
  * Get a reference to the Routing Service interface that we care about, and cache it in the Data Model.
  * This will allow us to lookup endpoints anywhere in the Asterisk SCF system.
  */
-void SipChannelService::locateRoutingService()
+void SipSessionManager::locateRoutingService()
 {
    if (mServiceLocator == 0)
    {
@@ -357,7 +357,7 @@ void SipChannelService::locateRoutingService()
    mRoutingServiceLocatorRegistry = pw;
 }
 
-void SipChannelService::locateStateReplicator()
+void SipSessionManager::locateStateReplicator()
 {
    if (mServiceLocator == 0)
    {
@@ -379,7 +379,7 @@ void SipChannelService::locateStateReplicator()
    }
 }
 
-void SipChannelService::registerWithStateReplicator()
+void SipSessionManager::registerWithStateReplicator()
 {
    if (mStateReplicator == 0)
    {
@@ -397,7 +397,7 @@ void SipChannelService::registerWithStateReplicator()
  * Get a reference to the Session Routing Service interface that we care about, and cache it in the Data Model.
  * This will allow us to route sessions.
  */
-void SipChannelService::locateSessionRouter()
+void SipSessionManager::locateSessionRouter()
 {
    if (mServiceLocator == 0)
    {
@@ -416,7 +416,7 @@ void SipChannelService::locateSessionRouter()
  * This is done at shutdown, and whenever we want to keep other services from locating
  * our interfaces.
  */
-void SipChannelService::deregisterFromServiceLocator()
+void SipSessionManager::deregisterFromServiceLocator()
 {
    try
    {
@@ -428,7 +428,7 @@ void SipChannelService::deregisterFromServiceLocator()
    }
 }
 
-void SipChannelService::configureEndpoints()
+void SipSessionManager::configureEndpoints()
 {
    Ice::PropertiesPtr props = mCommunicator->getProperties();
    Ice::StringSeq endpointNames = props->getPropertyAsList("Sip.Endpoints");
@@ -440,7 +440,7 @@ void SipChannelService::configureEndpoints()
    }
 }
 
-void SipChannelService::registerPJSipModules(pjsip_endpoint *endpt)
+void SipSessionManager::registerPJSipModules(pjsip_endpoint *endpt)
 {
    Ice::PropertiesPtr props = mCommunicator->getProperties();
    Ice::StringSeq moduleNames = props->getPropertyAsList("Sip.Modules");
@@ -465,7 +465,7 @@ void SipChannelService::registerPJSipModules(pjsip_endpoint *endpt)
    lg(Debug) << "Registered PJSIP modules";
 }
 
-void SipChannelService::deregisterFromStateReplicator()
+void SipSessionManager::deregisterFromStateReplicator()
 {
    if (mReplicaService->isActive() == true)
    {
@@ -479,7 +479,7 @@ void SipChannelService::deregisterFromStateReplicator()
  * Create the primary functional objects of this component.
  *   @param appName Name of the application or component.
  */
-void SipChannelService::initialize(const std::string appName, const Ice::CommunicatorPtr& ic)
+void SipSessionManager::initialize(const std::string appName, const Ice::CommunicatorPtr& ic)
 {
    try
    {
@@ -499,15 +499,15 @@ void SipChannelService::initialize(const std::string appName, const Ice::Communi
       lg(Debug) << "Created PJSIP manager";
 
       // Create the global adapter.
-      mGlobalAdapter = mCommunicator->createObjectAdapter("SipChannelServiceAdapter");
+      mGlobalAdapter = mCommunicator->createObjectAdapter("SipSessionManagerAdapter");
       lg(Debug) << "Created global object adapter";
 
       // Create the local adapter.
-      mLocalAdapter = mCommunicator->createObjectAdapter("SipChannelServiceLocalAdapter");
+      mLocalAdapter = mCommunicator->createObjectAdapter("SipSessionManagerLocalAdapter");
       lg(Debug) << "Created local object adapter";
 
-      mEventPublisher.reset(new SipChannelServiceEventPublisher(mLocalAdapter));
-      lg(Debug) << "Created SIP Channel Service event publisher";
+      mEventPublisher.reset(new SipSessionManagerEventPublisher(mLocalAdapter));
+      lg(Debug) << "Created SIP Session Manager event publisher";
 
       // We're not actually registering with the service locator at this point, but
       // several components we create could really use the proxy, so we create
@@ -523,7 +523,7 @@ void SipChannelService::initialize(const std::string appName, const Ice::Communi
       lg(Debug) << "Created SIP endpoint factory";
 
       // Create and configure our Endpoint Locator.
-      mEndpointLocator = new SipChannelServiceEndpointLocator(mEndpointFactory);
+      mEndpointLocator = new SipSessionManagerEndpointLocator(mEndpointFactory);
       mGlobalAdapter->add(mEndpointLocator, mCommunicator->stringToIdentity(EndpointLocatorObjectId));
       lg(Debug) << "Got proxy to endpoint locator";
 
@@ -553,7 +553,7 @@ void SipChannelService::initialize(const std::string appName, const Ice::Communi
 /**
  * Overload of the Ice::Application::run method.
  */
-void SipChannelService::start(const string& name, const Ice::CommunicatorPtr& ic, const Ice::StringSeq& args)
+void SipSessionManager::start(const string& name, const Ice::CommunicatorPtr& ic, const Ice::StringSeq& args)
 {
    // Initialize this component.
    initialize(name, ic);
@@ -585,7 +585,7 @@ void SipChannelService::start(const string& name, const Ice::CommunicatorPtr& ic
    }
 }
 
-void SipChannelService::stop()
+void SipSessionManager::stop()
 {
    // Remove our interfaces from the service locator.
    deregisterFromServiceLocator();
@@ -604,9 +604,9 @@ extern "C"
 {
 ASTERISK_SCF_ICEBOX_EXPORT IceBox::Service* create(Ice::CommunicatorPtr communicator)
 {
-   return new SipChannelService;
+   return new SipSessionManager;
 }
 }
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
@@ -317,9 +317,9 @@ void SipChannelService::registerWithServiceLocator()
  * Register our own Endpoint Locator with the Routing Service so that
  * the endpoints that this channel manages can be accessed from any
- * channel service in the Asterisk SCF system.
+ * Session Manager in the Asterisk SCF system.
  */
diff --git a/src/SipChannelServiceEndpointLocator.h b/src/SipSessionManagerEndpointLocator.h
similarity index 85%
rename from src/SipChannelServiceEndpointLocator.h
rename to src/SipSessionManagerEndpointLocator.h
index f195842..6cac295 100644
--- a/src/SipChannelServiceEndpointLocator.h
+++ b/src/SipSessionManagerEndpointLocator.h
@@ -21,19 +21,19 @@
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 /**
  * An implementation of the Routing Service EndpointLocator interface.
  * This class provides lookups of all the endpoints managed by this
  * Channel Service component, so that the rest of the Asterisk SCF system
  * can bridge our endpoints.
  */
-class SipChannelServiceEndpointLocator : public AsteriskSCF::Core::Routing::V1::EndpointLocator
+class SipSessionManagerEndpointLocator : public AsteriskSCF::Core::Routing::V1::EndpointLocator
 {
 public:
-SipChannelServiceEndpointLocator(boost::shared_ptr<SipEndpointFactory> factory) : mEndpointFactory(factory) { };
+SipSessionManagerEndpointLocator(boost::shared_ptr<SipEndpointFactory> factory) : mEndpointFactory(factory) { };
 
 public:  // Overrides of EndpointLocator
 
@@ -50,5 +50,5 @@ private:
    boost::shared_ptr<SipEndpointFactory> mEndpointFactory;
 };
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
@@ -21,19 +21,19 @@
  * An implementation of the Routing Service EndpointLocator interface.
  * This class provides lookups of all the endpoints managed by this
- * Channel Service component, so that the rest of the Asterisk SCF system
+ * Session Manager component, so that the rest of the Asterisk SCF system
  * can bridge our endpoints.
  */
diff --git a/src/SipChannelServiceEventPublisher.cpp b/src/SipSessionManagerEventPublisher.cpp
similarity index 77%
rename from src/SipChannelServiceEventPublisher.cpp
rename to src/SipSessionManagerEventPublisher.cpp
index 0655ae5..058244a 100644
--- a/src/SipChannelServiceEventPublisher.cpp
+++ b/src/SipSessionManagerEventPublisher.cpp
@@ -17,7 +17,7 @@
 #include <Ice/Ice.h>
 #include <IceStorm/IceStorm.h>
 
-#include "SipChannelServiceEventPublisher.h"
+#include "SipSessionManagerEventPublisher.h"
 #include "logger.h"
 
 using namespace ::std;
@@ -26,21 +26,21 @@ using namespace AsteriskSCF::System::Logging;
 
 namespace
 {
-Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipChannelService");
+Logger &lg = getLoggerFactory().getLogger("AsteriskSCF.SipSessionManager");
 }
 
 namespace AsteriskSCF
 {
-namespace SipChannelService
+namespace SipSessionManager
 {
 
 /**
  * The private implementation of SipChannelServiceEventPublisher.
  */
-class SipChannelServiceEventPublisherPriv
+class SipSessionManagerEventPublisherPriv
 {
 public:
-SipChannelServiceEventPublisherPriv(Ice::ObjectAdapterPtr adapter) :  mAdapter(adapter), mInitialized(false)
+SipSessionManagerEventPublisherPriv(Ice::ObjectAdapterPtr adapter) :  mAdapter(adapter), mInitialized(false)
    {
       initialize();
    }
@@ -63,7 +63,7 @@ SipChannelServiceEventPublisherPriv(Ice::ObjectAdapterPtr adapter) :  mAdapter(a
             return;
          }
 
-         lg(Debug) << "SipChannelServiceEventPublisher::initialize(): Got IceStorm proxy: TopicManager.Proxy";
+         lg(Debug) << "SipSessionManagerEventPublisher::initialize(): Got IceStorm proxy: TopicManager.Proxy";
       }
       catch(const IceUtil::Exception&)
       {
@@ -90,7 +90,7 @@ SipChannelServiceEventPublisherPriv(Ice::ObjectAdapterPtr adapter) :  mAdapter(a
       }
 
       Ice::ObjectPrx publisher = topic->getPublisher();
-      mEventTopic = Event::SipChannelServiceEventsPrx::uncheckedCast(publisher);
+      mEventTopic = Event::SipSessionManagerEventsPrx::uncheckedCast(publisher);
 
       mInitialized = true;
    }
@@ -102,14 +102,14 @@ SipChannelServiceEventPublisherPriv(Ice::ObjectAdapterPtr adapter) :  mAdapter(a
    {
       if (!mInitialized)
       {
-         lg(Error) << "Warning: Attempting to use SipChannelServiceEventPublisher in uninitialized state! IceStorm may be inaccessible.";
+         lg(Error) << "Warning: Attempting to use SipSessionManagerEventPublisher in uninitialized state! IceStorm may be inaccessible.";
       }
 
       return mInitialized;
    }
 
 public:
-   Event::SipChannelServiceEventsPrx mEventTopic;
+   Event::SipSessionManagerEventsPrx mEventTopic;
    Ice::ObjectAdapterPtr mAdapter;
    bool mInitialized;
 };
@@ -117,15 +117,15 @@ public:
 /**
  * Class constructor.
  */
-SipChannelServiceEventPublisher::SipChannelServiceEventPublisher(Ice::ObjectAdapterPtr adapter) 
-   : mImpl(new SipChannelServiceEventPublisherPriv(adapter))
+SipSessionManagerEventPublisher::SipSessionManagerEventPublisher(Ice::ObjectAdapterPtr adapter) 
+   : mImpl(new SipSessionManagerEventPublisherPriv(adapter))
 {
 }
 
 /**
  * Send a message to the service's event topic to report a lookup event.
  */
-void SipChannelServiceEventPublisher::sendLookupEvent(const ::std::string& destination,
+void SipSessionManagerEventPublisher::sendLookupEvent(const ::std::string& destination,
    ::AsteriskSCF::SIP::V1::Event::OperationResult result) const
 {
    if (!mImpl->isInitialized())
@@ -136,6 +136,6 @@ void SipChannelServiceEventPublisher::sendLookupEvent(const ::std::string& desti
    mImpl->mEventTopic->lookupEvent(destination, result);
 }
 
-}; // end SipChannelService
+}; // end SipSessionManager
 }; // end AsteriskSCF
 
@@ -26,21 +26,21 @@ using namespace AsteriskSCF::System::Logging;
 
 /**
- * The private implementation of SipChannelServiceEventPublisher.
+ * The private implementation of SipSessionManagerEventPublisher.
  */
-- 
asterisk-scf/integration/sip.git



More information about the asterisk-scf-commits mailing list